@@ -1,6 +1,7 @@
 package App::Mobirc::Plugin::StickyTime;
 use strict;
-use MooseX::Plaggerize::Plugin;
+use warnings;
+use App::Mobirc::Plugin;
 use App::Mobirc::Util;
 use HTML::StickyQuery;
 use App::Mobirc::Validator;
